function out3= Pos_Thrust3(in)
% Multi-Level RCS selection logic for the 10 thruster locations.
% Each thruster can fire at multiple levels (assuming multiple parallel 
% jets per location). Max throttle level per thruster is (1).
% A throttle command of (1) is equivalent to 2400 (lb) of total thrust 
% for the first 6 rear thrusters (three 800 (lb) paraller jets per location).
% A throttle command of (1) is equivalent to 1600 (lb) of total thrust 
% for the last 4 front thrusters (two 800 (lb) paraller jets per location).

% The mixing logic matrix KJmix2 converts the flight control demands into
% throttle commands for the thrusters, which can be both positive or
% negative. The logic fires only the +ve thrusters at twice the demanded 
% value and set the -ve thrusts to zero.

% The RCS activates only when attitude error magnitude (erm) is significant
% in(4) is the FCS output, an Input to the Mixing Logic KJmix2
% thro(j) is the demanded analogue throttle command for each jet (j)

global KJmix
out2=zeros(11,3);
thro= KJmix*in;
err= in(1:3); erm=sqrt(err'*err);

for i=1:11
    if (thro(i)>0 & erm>0.008)
        out(i)=2*thro(i);
    else
        out(i)=0;
    end
end

% Setup the 3-level logic for the rear thrusters
% Assumes that there are 3 similar jets per thruster location/direction 
% producing a total of 2400 (lb) of thrust per location
for i=1:6                                  % Rear Thrusters
    if out(i)>1/3                          % chk(1) greater than 1/3
        out2(i,1)=1/3;
        if out(i)>2/3                      % chk(2) greater than 2/3
            out2(i,2)=1/3;
            if out(i)>1                    % chk(3) greater than 3/3
                out2(i,3)=1/3;
            else                           % chk(3) less than 3/3
                out2(i,3)=out(i)-2/3;
            end
        else                               % chk(2) less than 2/3
            out2(i,2)=out(i)-1/3;
        end
    else                                   % chk(1) less than 1/3
        out2(i,1)=out(i);
    end
end

% Setup the 2-level logic for the front thrusters
% Assumes that there are two similar jets per thruster location/direction 
% producing a total of 1600 (lb) of thrust per location
for i=7:11                                 % Front Thrusters
    if out(i)>0.5                          % chk(1) greater than 0.5
        out2(i,1)=0.5;
        if out(i)>1                        % chk(2) greater than 1
            out2(i,2)=1;
        else                               % chk(2) less than 1
            out2(i,2)=out(i)-0.5;
        end
    else                                   % chk(1) less than 1/3
        out2(i,1)=out(i);
    end
end

% 11 groups of throttle command outputs for each throttling jet (alalog)
% three or two throttle command outputs per thruster group 
% (one for each jet in the group)
out3=[out2(1,:)'*3;    out2(2,:)'*3;   out2(3,:)'*3;   out2(4,:)'*3; ...
      out2(5,:)'*3;    out2(6,:)'*3; ...
      out2(7,1:2)'*2;  out2(8,1:2)'*2; out2(9,1:2)'*2; ...
      out2(10,1:2)'*2; out2(11,1:2)'*2; erm];